==> forms-v5.2.1.tar.gz: forms/l10n/mk.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Форми",
    "No" : "Не",
    "Yes" : "Да",
    "Question" : "Прашање",
    "Answer" : "Одговор",
    "Copy" : "Копирај",
    "Anonymous response" : "Анонимен одговор",
    "Shared by %s" : "Споделена од %s",
    "responses" : "одговори",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Едноставни истражувања и прашалници, самостојно хостирани",
    "An error occurred while loading the forms list" : "Грешка при вчитување на листата со форми",
    "Form not found" : "Формата не е пронајдена",
    "Unable to create a new form" : "Неможе да се креира нова форма",
    "New form" : "Нова форма",
    "Shared with you" : "Споделено со вас",
    "Loading forms …" : "Вчитување форми ...",
    "No forms created yet" : "Сеуште нема креирано форми",
    "Create a form" : "Креирај форма",
    "Select a form or create a new one" : "Избери форма или креирај нова",
    "Create new form" : "Креирај нова форма",
    "This form does not exist" : "Оваа форма не постои",
    "Form expired" : "Формата е истечена",
    "This form has expired and is no longer taking answers" : "Оваа форма е истечена и повеќе неможе да се внесуваат оговари",
    "Select groups" : "Одбери групи",
    "Delete form" : "Избриши форма",
    "Error while deleting {title}" : "Грешка при бришење на {title}",
    "Share form" : "Сподели форма",
    "Results" : "Резултати",
    "Are you sure you want to delete {title}?" : "Дали си сигурен дека сакаш да ја избришеш {title}?",
    "Cancel" : "Откажи",
    "Options" : "Опции",
    "Answer number {index}" : "Број на одговор {index}",
    "Error while saving the answer" : "Грешка при зачувување на одговор",
    "Delete answer" : "Избриши одговор",
    "This question needs a title!" : "Потербен е наслов на прашањето!",
    "Question number {index}" : "Прашање број {index}",
    "Title of question number {index}" : "Наслов на прашање број {index}",
    "Required" : "Задолжително",
    "Delete question" : "Избриши прашање",
    "Maximum file size" : "Максимална големина на датотека",
    "Delete" : "Избриши",
    "Uploading …" : "Прикачување …",
    "A long answer for the question “{text}”" : "Долг одговор за прашањето {index}",
    "Other" : "Останато",
    "A short answer for the question “{text}”" : "Краток одговор за прашањето {index}",
    "No response" : "Нема одговор",
    "Delete this response" : "Избриши го одговорот",
    "Expired on {date}" : "Истечено на {date}",
    "Expires on {date}" : "Истекува на {date}",
    "never" : "никогаш",
    "Allow multiple responses per person" : "Дозволи повеќе одговори од една личност",
    "Set expiration date" : "Постави рок на траење",
    "Group" : "Група",
    "Team" : "Тим",
    "Permissions" : "Дозволи",
    "Share link" : "Сподели линк",
    "Add link" : "Додади линк",
    "Copy to clipboard" : "Копирај во клипборд",
    "Copy embedding code" : "Копирај код за вградување",
    "Internal link" : "Внатрешен линк",
    "View" : "Погледни",
    "Edit" : "Уреди",
    "Share" : "Сподели",
    "Responses are anonymous." : "Одговорите се анонимни.",
    "An asterisk (*) indicates mandatory questions." : "Прашањата со ѕвездичка (*) се задолжителни.",
    "There was an error while adding the new question" : "Настана грешка при додавање на на ново прашање",
    "There was an error while removing the question" : "Настана грешка при бришење на прашање",
    "Error while saving form" : "Грешка при зачувување на форма",
    "Loading {title} …" : "Се вчитува {title} …",
    "Form title" : "Наслов на формата",
    "Description" : "Опис",
    "Add a question" : "Додади прашање",
    "Summary" : "Резиме",
    "Responses" : "Одговори",
    "There was an error while loading the results" : "Настана грешка при вчитување на резултатите",
    "There was an error while removing this response" : "Настана грешка при бришење на одговор",
    "There was an error while removing responses" : "Настана грешка при бришење на одговори",
    "{amount} responses" : "{amount} одговори",
    "Download" : "Преземи",
    "Delete all responses" : "Избриши ги сите одговори",
    "Search" : "Барај",
    "Loading responses …" : "Вчитување на одговори ...",
    "No results found" : "Нема пронајдено резултати",
    "No responses yet" : "Сеуште нема одговори",
    "Results of submitted forms will show up here" : "Резултатите од испратените прашалници ќе се појават овде",
    "Are you sure you want to delete all responses of {title}?" : "Дали сте сигурни дека сакате да ги избришете сите одговори на {title}?",
    "Sharing" : "Споделување",
    "Settings" : "Параметри",
    "Abort" : "Прекини",
    "Submit" : "Испрати",
    "Clear" : "Исчисти",
    "There was an error submitting the form" : "Настана грешка при испраќање на формата",
    "Submit form" : "Испрати",
    "Submitting form …" : "Испраќање форма ...",
    "Thank you for completing the form!" : "Ви благодариме што ја комплетиравте формата!",
    "Error while saving question" : "Грешка при зачувување на прашање",
    "There was an issue deleting this option" : "Настана грешка при бришење на опцијата",
    "Form link copied" : "Линкот до прашалникот е копиран",
    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
    "No recommendations. Start typing." : "Нема препораки. Започнете со пишување.",
    "No elements found." : "Нема пронајдено елементи.",
    "Checkboxes" : "Полиња за избирање",
    "Checkbox question title" : "Наслов на прашање со полe за избирање ",
    "This question needs a title and at least one answer!" : "Потребно е да внесете наслов на ова прашање и најмалку еден одговор!",
    "Dropdown" : "Паѓачки избор",
    "Dropdown question title" : "Наслов на прашање со паѓачки избор",
    "People can pick one option" : "Учесниците можат да изберат една опција",
    "Pick an option" : "Избери опција",
    "File" : "Датотека",
    "Short answer" : "Краток одговор",
    "Short answer question title" : "Наслов на прашање со краток одговор",
    "People can enter a short answer" : "Учесниците можат да внесат краток одговор",
    "Long text" : "Долг текст",
    "Long text question title" : "Наслов на прашање со долг текст",
    "People can enter a long text" : "Учесниците можат да внесат долг текст",
    "Date" : "Датум",
    "Date question title" : "Наслов на прашање со датум",
    "People can pick a date" : "Учесниците можат да изберат датум",
    "Pick a date" : "Избери датум",
    "Datetime" : "Датум-време",
    "Datetime question title" : "Наслов на прашање со датум-време",
    "People can pick a date and time" : "Учесниците можат да изберат датум и време",
    "Pick a date and time" : "Изберете датум и време",
    "Time" : "Време",
    "Pick a time" : "Избери време",
    "Color" : "Боја",
    "Image" : "Слика",
    "Document" : "Документ",
    "Presentation" : "Презентација",
    "Text" : "Текст",
    "Phone number" : "Телефонски број",
    "Email address" : "Е-пошта адреса"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> forms-v5.2.3.tar.gz: forms/l10n/mk.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Форми",
    "No" : "Не",
    "Yes" : "Да",
    "Question" : "Прашање",
    "Answer" : "Одговор",
    "Copy" : "Копирај",
    "Anonymous response" : "Анонимен одговор",
    "Shared by %s" : "Споделена од %s",
    "responses" : "одговори",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Едноставни истражувања и прашалници, самостојно хостирани",
    "An error occurred while loading the forms list" : "Грешка при вчитување на листата со форми",
    "Form not found" : "Формата не е пронајдена",
    "Unable to create a new form" : "Неможе да се креира нова форма",
    "New form" : "Нова форма",
    "Shared with you" : "Споделено со вас",
    "No forms created yet" : "Сеуште нема креирано форми",
    "Create a form" : "Креирај форма",
    "Select a form or create a new one" : "Избери форма или креирај нова",
    "Create new form" : "Креирај нова форма",
    "This form does not exist" : "Оваа форма не постои",
    "Form expired" : "Формата е истечена",
    "This form has expired and is no longer taking answers" : "Оваа форма е истечена и повеќе неможе да се внесуваат оговари",
    "Select groups" : "Одбери групи",
    "Delete form" : "Избриши форма",
    "Error while deleting {title}" : "Грешка при бришење на {title}",
    "Share form" : "Сподели форма",
    "Results" : "Резултати",
    "Are you sure you want to delete {title}?" : "Дали си сигурен дека сакаш да ја избришеш {title}?",
    "Cancel" : "Откажи",
    "Options" : "Опции",
    "Answer number {index}" : "Број на одговор {index}",
    "Error while saving the answer" : "Грешка при зачувување на одговор",
    "Delete answer" : "Избриши одговор",
    "This question needs a title!" : "Потербен е наслов на прашањето!",
    "Question number {index}" : "Прашање број {index}",
    "Title of question number {index}" : "Наслов на прашање број {index}",
    "Required" : "Задолжително",
    "Delete question" : "Избриши прашање",
    "Maximum file size" : "Максимална големина на датотека",
    "Delete" : "Избриши",
    "A long answer for the question “{text}”" : "Долг одговор за прашањето {index}",
    "Other" : "Останато",
    "A short answer for the question “{text}”" : "Краток одговор за прашањето {index}",
    "No response" : "Нема одговор",
    "Delete this response" : "Избриши го одговорот",
    "Expired on {date}" : "Истечено на {date}",
    "Expires on {date}" : "Истекува на {date}",
    "never" : "никогаш",
    "Allow multiple responses per person" : "Дозволи повеќе одговори од една личност",
    "Set expiration date" : "Постави рок на траење",
    "Group" : "Група",
    "Team" : "Тим",
    "Permissions" : "Дозволи",
    "Share link" : "Сподели линк",
    "Add link" : "Додади линк",
    "Copy to clipboard" : "Копирај во клипборд",
    "Copy embedding code" : "Копирај код за вградување",
    "Internal link" : "Внатрешен линк",
    "View" : "Погледни",
    "Edit" : "Уреди",
    "Share" : "Сподели",
    "Responses are anonymous." : "Одговорите се анонимни.",
    "An asterisk (*) indicates mandatory questions." : "Прашањата со ѕвездичка (*) се задолжителни.",
    "There was an error while adding the new question" : "Настана грешка при додавање на на ново прашање",
    "There was an error while removing the question" : "Настана грешка при бришење на прашање",
    "Error while saving form" : "Грешка при зачувување на форма",
    "Form title" : "Наслов на формата",
    "Description" : "Опис",
    "Add a question" : "Додади прашање",
    "Summary" : "Резиме",
    "Responses" : "Одговори",
    "There was an error while loading the results" : "Настана грешка при вчитување на резултатите",
    "There was an error while removing this response" : "Настана грешка при бришење на одговор",
    "There was an error while removing responses" : "Настана грешка при бришење на одговори",
    "{amount} responses" : "{amount} одговори",
    "Download" : "Преземи",
    "Delete all responses" : "Избриши ги сите одговори",
    "Search" : "Барај",
    "No results found" : "Нема пронајдено резултати",
    "No responses yet" : "Сеуште нема одговори",
    "Results of submitted forms will show up here" : "Резултатите од испратените прашалници ќе се појават овде",
    "Are you sure you want to delete all responses of {title}?" : "Дали сте сигурни дека сакате да ги избришете сите одговори на {title}?",
    "Sharing" : "Споделување",
    "Settings" : "Параметри",
    "Abort" : "Прекини",
    "Submit" : "Испрати",
    "Clear" : "Исчисти",
    "There was an error submitting the form" : "Настана грешка при испраќање на формата",
    "Submit form" : "Испрати",
    "Thank you for completing the form!" : "Ви благодариме што ја комплетиравте формата!",
    "Error while saving question" : "Грешка при зачувување на прашање",
    "There was an issue deleting this option" : "Настана грешка при бришење на опцијата",
    "Form link copied" : "Линкот до прашалникот е копиран",
    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
    "No recommendations. Start typing." : "Нема препораки. Започнете со пишување.",
    "No elements found." : "Нема пронајдено елементи.",
    "Checkboxes" : "Полиња за избирање",
    "Checkbox question title" : "Наслов на прашање со полe за избирање ",
    "This question needs a title and at least one answer!" : "Потребно е да внесете наслов на ова прашање и најмалку еден одговор!",
    "Dropdown" : "Паѓачки избор",
    "Dropdown question title" : "Наслов на прашање со паѓачки избор",
    "People can pick one option" : "Учесниците можат да изберат една опција",
    "Pick an option" : "Избери опција",
    "File" : "Датотека",
    "Short answer" : "Краток одговор",
    "Short answer question title" : "Наслов на прашање со краток одговор",
    "People can enter a short answer" : "Учесниците можат да внесат краток одговор",
    "Long text" : "Долг текст",
    "Long text question title" : "Наслов на прашање со долг текст",
    "People can enter a long text" : "Учесниците можат да внесат долг текст",
    "Date" : "Датум",
    "Date question title" : "Наслов на прашање со датум",
    "People can pick a date" : "Учесниците можат да изберат датум",
    "Pick a date" : "Избери датум",
    "Datetime" : "Датум-време",
    "Datetime question title" : "Наслов на прашање со датум-време",
    "People can pick a date and time" : "Учесниците можат да изберат датум и време",
    "Pick a date and time" : "Изберете датум и време",
    "Time" : "Време",
    "Pick a time" : "Избери време",
    "Color" : "Боја",
    "Image" : "Слика",
    "Document" : "Документ",
    "Presentation" : "Презентација",
    "Text" : "Текст",
    "Phone number" : "Телефонски број",
    "Email address" : "Е-пошта адреса",
    "Loading forms …" : "Вчитување форми ...",
    "Uploading …" : "Прикачување …",
    "Loading {title} …" : "Се вчитува {title} …",
    "Loading responses …" : "Вчитување на одговори ...",
    "Submitting form …" : "Испраќање форма ..."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
